==> PyMandel-1.0.0.tar.gz: PyMandel-1.0.0/colormaps/tropical_colormap.py <==
from numpy import array

'''
16-level colormap created by make_colormap utility from file tropical256.png
'''
tropical16 = array([ \
[3, 72, 0], [24, 111, 10], [51, 147, 22], [219, 188, 47],
[240, 131, 42], [243, 61, 33], [217, 66, 40], [191, 71, 46],
[134, 81, 80], [126, 78, 186], [125, 92, 254], [140, 155, 251],
[162, 246, 245], [112, 225, 91], [100, 186, 44], [93, 12, 70]])
'''
End of colormap from tropical256.png
'''

'''
256-level colormap created by make_colormap utility from file tropical256.png
'''
tropical256 = array([ \
[9, 41, 4], [9, 42, 3], [9, 44, 4], [8, 45, 4],
[8, 47, 3], [8, 48, 3], [7, 50, 3], [7, 51, 3],
[7, 52, 3], [7, 54, 3], [7, 55, 3], [6, 56, 2],
[6, 58, 3], [6, 59, 2], [5, 61, 2], [5, 63, 2],
[4, 66, 2], [4, 68, 1], [3, 71, 1], [3, 74, 0],
[2, 76, 1], [2, 79, 0], [4, 81, 1], [5, 84, 1],
[7, 86, 2], [9, 89, 3], [10, 91, 4], [12, 94, 5],
[14, 96, 6], [16, 99, 6], [17, 101, 7], [19, 103, 8],
[21, 106, 8], [23, 109, 10], [25, 111, 10], [26, 113, 11],
[28, 116, 12], [30, 118, 13], [31, 121, 14], [33, 123, 14],
[35, 126, 15], [37, 128, 16], [38, 130, 16], [40, 133, 17],
[42, 135, 18], [44, 138, 19], [45, 140, 20], [47, 143, 21],
[49, 145, 21], [51, 147, 22], [60, 149, 23], [70, 152, 25],
[79, 154, 26], [88, 156, 27], [97, 158, 29], [106, 160, 30],
[115, 163, 31], [124, 165, 33], [133, 167, 34], [142, 169, 35],
[151, 171, 37], [159, 173, 38], [168, 175, 39], [177, 177, 40],
[185, 179, 42], [194, 181, 43], [202, 183, 44], [211, 185, 45],
[219, 187, 47], [228, 189, 48], [236, 192, 49], [236, 187, 49],
[236, 182, 48], [236, 177, 48], [237, 173, 47], [237, 168, 46],
[238, 164, 46], [237, 159, 45], [238, 155, 45], [238, 150, 44],
[238, 145, 44], [239, 141, 43], [239, 136, 43], [239, 132, 42],
[240, 127, 41], [240, 122, 41], [240, 118, 41], [240, 113, 40],
[241, 108, 40], [241, 104, 39], [241, 99, 38], [241, 94, 38],
[242, 90, 37], [242, 85, 37], [242, 81, 36], [242, 76, 35],
[243, 72, 35], [243, 67, 35], [243, 62, 34], [242, 61, 34],
[240, 62, 35], [239, 62, 35], [237, 62, 35], [235, 63, 36],
[234, 63, 36], [232, 63, 36], [230, 63, 37], [228, 64, 37],
[226, 64, 38], [225, 65, 38], [223, 65, 39], [222, 65, 39],
[220, 65, 40], [218, 66, 40], [216, 66, 40], [214, 67, 41],
[213, 67, 41], [211, 67, 41], [209, 67, 42], [208, 68, 42],
[206, 68, 43], [204, 68, 44], [203, 69, 44], [201, 69, 44],
[199, 69, 44], [197, 70, 45], [195, 70, 46], [194, 70, 46],
[193, 71, 46], [191, 71, 47], [189, 72, 47], [184, 72, 49],
[179, 73, 49], [175, 74, 50], [170, 75, 52], [165, 76, 53],
[161, 77, 54], [156, 77, 55], [151, 78, 56], [146, 79, 58],
[141, 80, 59], [137, 81, 60], [135, 81, 65], [134, 81, 72],
[134, 81, 79], [133, 81, 86], [133, 80, 93], [132, 80, 100],
[132, 80, 106], [131, 80, 114], [131, 80, 120], [130, 79, 127],
[130, 79, 134], [129, 79, 141], [128, 79, 148], [128, 78, 155],
[128, 79, 161], [127, 78, 169], [126, 78, 175], [126, 78, 182],
[126, 78, 189], [125, 77, 196], [125, 77, 203], [124, 77, 210],
[124, 77, 217], [123, 76, 223], [122, 76, 230], [122, 76, 237],
[121, 76, 244], [121, 76, 251], [121, 77, 255], [122, 80, 255],
[122, 83, 254], [123, 87, 254], [124, 90, 254], [125, 94, 254],
[126, 97, 254], [127, 100, 253], [127, 103, 253], [128, 107, 253],
[129, 110, 253], [130, 113, 253], [130, 117, 253], [131, 120, 252],
[132, 123, 252], [133, 127, 252], [134, 130, 251], [134, 133, 252],
[136, 136, 251], [136, 140, 251], [137, 143, 251], [138, 147, 251],
[138, 150, 250], [140, 153, 250], [140, 156, 250], [141, 160, 250],
[142, 163, 249], [143, 167, 250], [145, 174, 249], [146, 181, 249],
[148, 187, 248], [149, 194, 248], [151, 201, 248], [152, 207, 247],
[154, 214, 247], [156, 220, 247], [157, 227, 246], [159, 233, 246],
[161, 240, 245], [162, 247, 245], [164, 253, 244], [162, 254, 238],
[159, 252, 229], [156, 250, 221], [153, 249, 213], [151, 247, 204],
[147, 246, 196], [144, 244, 187], [141, 243, 179], [138, 241, 170],
[136, 239, 162], [131, 237, 148], [125, 233, 130], [118, 229, 111],
[112, 226, 92], [105, 222, 74], [104, 221, 71], [104, 220, 69],
[104, 218, 68], [104, 215, 66], [103, 213, 65], [103, 211, 63],
[103, 209, 61], [102, 206, 59], [102, 203, 57], [102, 200, 54],
[101, 197, 52], [101, 193, 50], [100, 191, 48], [100, 187, 45],
[100, 184, 42], [99, 180, 40], [99, 177, 37], [98, 173, 34],
[98, 170, 31], [97, 166, 29], [97, 162, 26], [96, 158, 23],
[96, 154, 20], [95, 150, 17], [95, 146, 14], [95, 142, 11],
[94, 138, 8], [93, 134, 5], [93, 130, 2], [93, 129, 2]])
'''
End of colormap from file tropical256.png
'''

==> PyMandel-1.0.8.tar.gz: PyMandel-1.0.8/colormaps/tropical_colormap.py <==
from numpy import array

#****************************************************************************************
# 16-level colormap created by make_colormap utility from file tropical256.png
#****************************************************************************************
tropical16 = array([ \
[3, 72, 0], [24, 111, 10], [51, 147, 22], [219, 188, 47],
[240, 131, 42], [243, 61, 33], [217, 66, 40], [191, 71, 46],
[134, 81, 80], [126, 78, 186], [125, 92, 254], [140, 155, 251],
[162, 246, 245], [112, 225, 91], [100, 186, 44], [93, 12, 70]])

#****************************************************************************************
# 256-level colormap created by make_colormap utility from file tropical256.png
#****************************************************************************************
tropical256 = array([ \
[9, 41, 4], [9, 42, 3], [9, 44, 4], [8, 45, 4],
[8, 47, 3], [8, 48, 3], [7, 50, 3], [7, 51, 3],
[7, 52, 3], [7, 54, 3], [7, 55, 3], [6, 56, 2],
[6, 58, 3], [6, 59, 2], [5, 61, 2], [5, 63, 2],
[4, 66, 2], [4, 68, 1], [3, 71, 1], [3, 74, 0],
[2, 76, 1], [2, 79, 0], [4, 81, 1], [5, 84, 1],
[7, 86, 2], [9, 89, 3], [10, 91, 4], [12, 94, 5],
[14, 96, 6], [16, 99, 6], [17, 101, 7], [19, 103, 8],
[21, 106, 8], [23, 109, 10], [25, 111, 10], [26, 113, 11],
[28, 116, 12], [30, 118, 13], [31, 121, 14], [33, 123, 14],
[35, 126, 15], [37, 128, 16], [38, 130, 16], [40, 133, 17],
[42, 135, 18], [44, 138, 19], [45, 140, 20], [47, 143, 21],
[49, 145, 21], [51, 147, 22], [60, 149, 23], [70, 152, 25],
[79, 154, 26], [88, 156, 27], [97, 158, 29], [106, 160, 30],
[115, 163, 31], [124, 165, 33], [133, 167, 34], [142, 169, 35],
[151, 171, 37], [159, 173, 38], [168, 175, 39], [177, 177, 40],
[185, 179, 42], [194, 181, 43], [202, 183, 44], [211, 185, 45],
[219, 187, 47], [228, 189, 48], [236, 192, 49], [236, 187, 49],
[236, 182, 48], [236, 177, 48], [237, 173, 47], [237, 168, 46],
[238, 164, 46], [237, 159, 45], [238, 155, 45], [238, 150, 44],
[238, 145, 44], [239, 141, 43], [239, 136, 43], [239, 132, 42],
[240, 127, 41], [240, 122, 41], [240, 118, 41], [240, 113, 40],
[241, 108, 40], [241, 104, 39], [241, 99, 38], [241, 94, 38],
[242, 90, 37], [242, 85, 37], [242, 81, 36], [242, 76, 35],
[243, 72, 35], [243, 67, 35], [243, 62, 34], [242, 61, 34],
[240, 62, 35], [239, 62, 35], [237, 62, 35], [235, 63, 36],
[234, 63, 36], [232, 63, 36], [230, 63, 37], [228, 64, 37],
[226, 64, 38], [225, 65, 38], [223, 65, 39], [222, 65, 39],
[220, 65, 40], [218, 66, 40], [216, 66, 40], [214, 67, 41],
[213, 67, 41], [211, 67, 41], [209, 67, 42], [208, 68, 42],
[206, 68, 43], [204, 68, 44], [203, 69, 44], [201, 69, 44],
[199, 69, 44], [197, 70, 45], [195, 70, 46], [194, 70, 46],
[193, 71, 46], [191, 71, 47], [189, 72, 47], [184, 72, 49],
[179, 73, 49], [175, 74, 50], [170, 75, 52], [165, 76, 53],
[161, 77, 54], [156, 77, 55], [151, 78, 56], [146, 79, 58],
[141, 80, 59], [137, 81, 60], [135, 81, 65], [134, 81, 72],
[134, 81, 79], [133, 81, 86], [133, 80, 93], [132, 80, 100],
[132, 80, 106], [131, 80, 114], [131, 80, 120], [130, 79, 127],
[130, 79, 134], [129, 79, 141], [128, 79, 148], [128, 78, 155],
[128, 79, 161], [127, 78, 169], [126, 78, 175], [126, 78, 182],
[126, 78, 189], [125, 77, 196], [125, 77, 203], [124, 77, 210],
[124, 77, 217], [123, 76, 223], [122, 76, 230], [122, 76, 237],
[121, 76, 244], [121, 76, 251], [121, 77, 255], [122, 80, 255],
[122, 83, 254], [123, 87, 254], [124, 90, 254], [125, 94, 254],
[126, 97, 254], [127, 100, 253], [127, 103, 253], [128, 107, 253],
[129, 110, 253], [130, 113, 253], [130, 117, 253], [131, 120, 252],
[132, 123, 252], [133, 127, 252], [134, 130, 251], [134, 133, 252],
[136, 136, 251], [136, 140, 251], [137, 143, 251], [138, 147, 251],
[138, 150, 250], [140, 153, 250], [140, 156, 250], [141, 160, 250],
[142, 163, 249], [143, 167, 250], [145, 174, 249], [146, 181, 249],
[148, 187, 248], [149, 194, 248], [151, 201, 248], [152, 207, 247],
[154, 214, 247], [156, 220, 247], [157, 227, 246], [159, 233, 246],
[161, 240, 245], [162, 247, 245], [164, 253, 244], [162, 254, 238],
[159, 252, 229], [156, 250, 221], [153, 249, 213], [151, 247, 204],
[147, 246, 196], [144, 244, 187], [141, 243, 179], [138, 241, 170],
[136, 239, 162], [131, 237, 148], [125, 233, 130], [118, 229, 111],
[112, 226, 92], [105, 222, 74], [104, 221, 71], [104, 220, 69],
[104, 218, 68], [104, 215, 66], [103, 213, 65], [103, 211, 63],
[103, 209, 61], [102, 206, 59], [102, 203, 57], [102, 200, 54],
[101, 197, 52], [101, 193, 50], [100, 191, 48], [100, 187, 45],
[100, 184, 42], [99, 180, 40], [99, 177, 37], [98, 173, 34],
[98, 170, 31], [97, 166, 29], [97, 162, 26], [96, 158, 23],
[96, 154, 20], [95, 150, 17], [95, 146, 14], [95, 142, 11],
[94, 138, 8], [93, 134, 5], [93, 130, 2], [93, 129, 2]])
